# geosdhydro

[![ci](https://github.com/csiro-hydroinformatics/geosdhydro/workflows/ci/badge.svg)](https://github.com/csiro-hydroinformatics/geosdhydro/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs-708FCC.svg?style=flat)](https://csiro-hydroinformatics.github.io/geosdhydro/)
[![pypi version](https://img.shields.io/pypi/v/geosdhydro.svg)](https://pypi.org/project/geosdhydro/)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://app.gitter.im/#/room/#geosdhydro:gitter.im)

**Geo**spatial tools for **s**emi-**d**istributed **hydro**logic modelling

## Installation

You may use [`uv`](https://docs.astral.sh/uv/) (recommended) to manage venvs and install packages. Optional.

```bash
pip install geosdhydro
# uv pip install geosdhydro
```

To install from the latest git main branch:

```bash
pip install git+https://github.com/csiro-hydroinformatics/geosdhydro@main
# uv pip install git+https://github.com/csiro-hydroinformatics/geosdhydro@main
```

<!-- With [`uv`](https://docs.astral.sh/uv/):

```bash
uv tool install geosdhydro
``` -->

## Usage

See the documentation link above for sample notebook(s).

There may be some command line features also available in the future, TBC.
